pub struct BorderModifier {
pub color: [f32; 4],
pub width: f32,
}Expand description
BorderModifier draws a solid-color border around the view bounds.
Fields
color: [f32; 4]width: f32Trait Implementations
Sourceimpl Clone for BorderModifier
impl Clone for BorderModifier
Sourcefn clone(&self) -> BorderModifier
fn clone(&self) -> BorderModifier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for BorderModifier
Sourceimpl Debug for BorderModifier
impl Debug for BorderModifier
Sourceimpl PartialEq for BorderModifier
impl PartialEq for BorderModifier
Sourcefn eq(&self, other: &BorderModifier) -> bool
fn eq(&self, other: &BorderModifier) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for BorderModifier
Sourceimpl ViewModifier for BorderModifier
impl ViewModifier for BorderModifier
fn modify<V: View>(self, content: V) -> impl View
Sourcefn render(&self, renderer: &mut dyn Renderer, rect: Rect)
fn render(&self, renderer: &mut dyn Renderer, rect: Rect)
Core rendering hook called before child views.
Sourcefn get_grid_placement(&self) -> Option<GridPlacement>
fn get_grid_placement(&self) -> Option<GridPlacement>
Returns the grid placement configuration if this modifier defines one.
Sourcefn post_render(&self, _renderer: &mut dyn Renderer, _rect: Rect)
fn post_render(&self, _renderer: &mut dyn Renderer, _rect: Rect)
Cleanup hook called after child views.
Sourcefn render_view<V: View>(
&self,
view: &V,
renderer: &mut dyn Renderer,
rect: Rect,
)
fn render_view<V: View>( &self, view: &V, renderer: &mut dyn Renderer, rect: Rect, )
Allows a modifier to completely override or wrap the rendering of its child.
Default implementation performs a standard push -> transform -> render child -> pop sequence.
fn transform_rect(&self, rect: Rect) -> Rect
Sourcefn transform_proposal(&self, proposal: SizeProposal) -> SizeProposal
fn transform_proposal(&self, proposal: SizeProposal) -> SizeProposal
Allows a modifier to transform the layout proposal before it reaches the child.
Sourcefn transform_size(&self, size: Size) -> Size
fn transform_size(&self, size: Size) -> Size
Allows a modifier to transform the resulting size from the child.
Sourcefn measure_view<V: View>(
&self,
view: &V,
renderer: &mut dyn Renderer,
proposal: SizeProposal,
) -> Size
fn measure_view<V: View>( &self, view: &V, renderer: &mut dyn Renderer, proposal: SizeProposal, ) -> Size
Measure hook that coordinates size propagation.
Sourcefn child_flex_weight<V: View>(&self, view: &V) -> f32
fn child_flex_weight<V: View>(&self, view: &V) -> f32
Allows a modifier to override or pass through the child’s flex weight.
fn layout(&self) -> Option<&dyn LayoutView>