pub struct Color {
pub r: f32,
pub g: f32,
pub b: f32,
pub a: f32,
}Expand description
A color represented by RGBA components in the [0.0, 1.0] range.
Fields
r: f32g: f32b: f32a: f32Implementations
Sourceimpl Color
impl Color
pub const BLACK: Color
pub const WHITE: Color
pub const TRANSPARENT: Color
pub const RED: Color
pub const GREEN: Color
pub const BLUE: Color
pub const VIKING_GOLD: Color
pub const MAGENTA_LIQUID: Color
pub const TACTICAL_OBSIDIAN: Color
pub const CYAN: Color
pub const YELLOW: Color
pub const MAGENTA: Color
pub const GRAY: Color
Sourcepub fn relative_luminance(&self) -> f32
pub fn relative_luminance(&self) -> f32
Calculate the relative luminance of the color as defined by WCAG 2.x
Sourcepub fn contrast_ratio(&self, other: &Color) -> f32
pub fn contrast_ratio(&self, other: &Color) -> f32
Calculate the contrast ratio between this color and another color