pub struct MjolnirSliceModifier {
pub angle: f32,
pub offset: f32,
}Expand description
MjolnirSliceModifier implements the “Geometric Slice” aesthetic. It uses a signed distance field (SDF) to clip the view along a sharp angled line.
Fields
angle: f32offset: f32Trait Implementations
Sourceimpl Clone for MjolnirSliceModifier
impl Clone for MjolnirSliceModifier
Sourcefn clone(&self) -> MjolnirSliceModifier
fn clone(&self) -> MjolnirSliceModifier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for MjolnirSliceModifier
Sourceimpl Debug for MjolnirSliceModifier
impl Debug for MjolnirSliceModifier
Sourceimpl PartialEq for MjolnirSliceModifier
impl PartialEq for MjolnirSliceModifier
Sourcefn eq(&self, other: &MjolnirSliceModifier) -> bool
fn eq(&self, other: &MjolnirSliceModifier) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for MjolnirSliceModifier
Sourceimpl ViewModifier for MjolnirSliceModifier
impl ViewModifier for MjolnirSliceModifier
fn modify<V: View>(self, content: V) -> impl View
Sourcefn render(&self, renderer: &mut dyn Renderer, _rect: Rect)
fn render(&self, renderer: &mut dyn Renderer, _rect: Rect)
Core rendering hook called before child views.
Sourcefn post_render(&self, renderer: &mut dyn Renderer, _rect: Rect)
fn post_render(&self, renderer: &mut dyn Renderer, _rect: Rect)
Cleanup hook called after child views.
Sourcefn get_grid_placement(&self) -> Option<GridPlacement>
fn get_grid_placement(&self) -> Option<GridPlacement>
Returns the grid placement configuration if this modifier defines one.
Sourcefn render_view<V: View>(
&self,
view: &V,
renderer: &mut dyn Renderer,
rect: Rect,
)
fn render_view<V: View>( &self, view: &V, renderer: &mut dyn Renderer, rect: Rect, )
Allows a modifier to completely override or wrap the rendering of its child.
Default implementation performs a standard push -> transform -> render child -> pop sequence.
fn transform_rect(&self, rect: Rect) -> Rect
Sourcefn transform_proposal(&self, proposal: SizeProposal) -> SizeProposal
fn transform_proposal(&self, proposal: SizeProposal) -> SizeProposal
Allows a modifier to transform the layout proposal before it reaches the child.
Sourcefn transform_size(&self, size: Size) -> Size
fn transform_size(&self, size: Size) -> Size
Allows a modifier to transform the resulting size from the child.
Sourcefn measure_view<V: View>(
&self,
view: &V,
renderer: &mut dyn Renderer,
proposal: SizeProposal,
) -> Size
fn measure_view<V: View>( &self, view: &V, renderer: &mut dyn Renderer, proposal: SizeProposal, ) -> Size
Measure hook that coordinates size propagation.
Sourcefn child_flex_weight<V: View>(&self, view: &V) -> f32
fn child_flex_weight<V: View>(&self, view: &V) -> f32
Allows a modifier to override or pass through the child’s flex weight.
fn layout(&self) -> Option<&dyn LayoutView>