pub struct OpacityModifier {
pub opacity: f32,
}Expand description
OpacityModifier fades this view and all its descendants to the given alpha.
The renderer is expected to honour push_opacity/pop_opacity on the Renderer trait.
Fields
opacity: f32Trait Implementations
Sourceimpl Clone for OpacityModifier
impl Clone for OpacityModifier
Sourcefn clone(&self) -> OpacityModifier
fn clone(&self) -> OpacityModifier
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreimpl Copy for OpacityModifier
Sourceimpl Debug for OpacityModifier
impl Debug for OpacityModifier
Sourceimpl PartialEq for OpacityModifier
impl PartialEq for OpacityModifier
Sourcefn eq(&self, other: &OpacityModifier) -> bool
fn eq(&self, other: &OpacityModifier) -> bool
Tests for
self and other values to be equal, and is used by ==.impl StructuralPartialEq for OpacityModifier
Sourceimpl ViewModifier for OpacityModifier
impl ViewModifier for OpacityModifier
fn modify<V: View>(self, content: V) -> impl View
Sourcefn render(&self, renderer: &mut dyn Renderer, _rect: Rect)
fn render(&self, renderer: &mut dyn Renderer, _rect: Rect)
Core rendering hook called before child views.
Sourcefn post_render(&self, renderer: &mut dyn Renderer, _rect: Rect)
fn post_render(&self, renderer: &mut dyn Renderer, _rect: Rect)
Cleanup hook called after child views.
Sourcefn get_grid_placement(&self) -> Option<GridPlacement>
fn get_grid_placement(&self) -> Option<GridPlacement>
Returns the grid placement configuration if this modifier defines one.
Sourcefn render_view<V: View>(
&self,
view: &V,
renderer: &mut dyn Renderer,
rect: Rect,
)
fn render_view<V: View>( &self, view: &V, renderer: &mut dyn Renderer, rect: Rect, )
Allows a modifier to completely override or wrap the rendering of its child.
Default implementation performs a standard push -> transform -> render child -> pop sequence.
fn transform_rect(&self, rect: Rect) -> Rect
Sourcefn transform_proposal(&self, proposal: SizeProposal) -> SizeProposal
fn transform_proposal(&self, proposal: SizeProposal) -> SizeProposal
Allows a modifier to transform the layout proposal before it reaches the child.
Sourcefn transform_size(&self, size: Size) -> Size
fn transform_size(&self, size: Size) -> Size
Allows a modifier to transform the resulting size from the child.
Sourcefn measure_view<V: View>(
&self,
view: &V,
renderer: &mut dyn Renderer,
proposal: SizeProposal,
) -> Size
fn measure_view<V: View>( &self, view: &V, renderer: &mut dyn Renderer, proposal: SizeProposal, ) -> Size
Measure hook that coordinates size propagation.
Sourcefn child_flex_weight<V: View>(&self, view: &V) -> f32
fn child_flex_weight<V: View>(&self, view: &V) -> f32
Allows a modifier to override or pass through the child’s flex weight.
fn layout(&self) -> Option<&dyn LayoutView>