pub struct StyleResolver;Expand description
StyleResolver provides high-level access to themed values from the environment.
Implementations
Sourceimpl StyleResolver
impl StyleResolver
Sourcepub fn color_array(key: &str) -> [f32; 4]
pub fn color_array(key: &str) -> [f32; 4]
Resolve a color from the current environment as a [f32; 4] RGBA array. Returns the color value for the current appearance (light/dark). Falls back to magenta (#FF00FF) if the key is not found.