pub struct UndoManager { /* private fields */ }Expand description
Unified manager for undo and redo stacks. Supports grouping of actions, max undo depth clamping, and coalescing.
Implementations
Sourceimpl UndoManager
impl UndoManager
Sourcepub fn new(max_depth: usize, coalesce_window: f32) -> Self
pub fn new(max_depth: usize, coalesce_window: f32) -> Self
Create a new UndoManager with custom settings.
Sourcepub fn push(
&mut self,
label: &str,
undo: impl Fn() + Send + Sync + 'static,
redo: impl Fn() + Send + Sync + 'static,
)
pub fn push( &mut self, label: &str, undo: impl Fn() + Send + Sync + 'static, redo: impl Fn() + Send + Sync + 'static, )
Push a new undo/redo group to the stack, clearing any forward redo history.
Sourcepub fn undo(&mut self) -> Option<Arc<dyn Fn() + Send + Sync>>
pub fn undo(&mut self) -> Option<Arc<dyn Fn() + Send + Sync>>
Perform the undo action if possible, moving the position back. Returns the undo closure to be executed outside of any state lock.
Sourcepub fn redo(&mut self) -> Option<Arc<dyn Fn() + Send + Sync>>
pub fn redo(&mut self) -> Option<Arc<dyn Fn() + Send + Sync>>
Perform the redo action if possible, moving the position forward. Returns the redo closure to be executed outside of any state lock.
Sourcepub fn push_coalesceable(
&mut self,
label: &str,
undo: impl Fn() + Send + Sync + 'static,
redo: impl Fn() + Send + Sync + 'static,
)
pub fn push_coalesceable( &mut self, label: &str, undo: impl Fn() + Send + Sync + 'static, redo: impl Fn() + Send + Sync + 'static, )
Push a new coalesceable action. If the last action in the stack matches the label, is within the coalesce window, and the position is at the end of the stack, their undo/redo functions will be combined instead of creating a new group.