pub struct FrameModifier {
pub width: Option<f32>,
pub height: Option<f32>,
pub min_width: Option<f32>,
pub max_width: Option<f32>,
pub min_height: Option<f32>,
pub max_height: Option<f32>,
pub alignment: Alignment,
}Expand description
Modifier to set the size and alignment constraints of a view. This determines the proposal size passed to the child and how the child is aligned within the layout rect allocated to the frame.
Fields
width: Option<f32>Exact width to assign to the child view.
height: Option<f32>Exact height to assign to the child view.
min_width: Option<f32>Minimum width constraint for the view.
max_width: Option<f32>Maximum width constraint for the view.
min_height: Option<f32>Minimum height constraint for the view.
max_height: Option<f32>Maximum height constraint for the view.
alignment: AlignmentThe alignment strategy for positioning the child view within the frame.
Implementations
Sourceimpl FrameModifier
impl FrameModifier
Sourcepub fn new() -> Self
pub fn new() -> Self
Creates a new FrameModifier with all dimensions unspecified and center alignment.
Sourcepub fn size(self, width: f32, height: f32) -> Self
pub fn size(self, width: f32, height: f32) -> Self
Sets both the fixed width and height of the frame.
Sourcepub fn min_height(self, min_height: f32) -> Self
pub fn min_height(self, min_height: f32) -> Self
Sets the minimum height constraint.
Sourcepub fn max_height(self, max_height: f32) -> Self
pub fn max_height(self, max_height: f32) -> Self
Sets the maximum height constraint.